==> haskell-zip-archive-0.4.3-5-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-zip-archive.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 zip-archive
version:              0.4.3
visibility:           public
id:                   zip-archive-0.4.3-11lrb3wXzGi31DiUgTzUJU
key:                  zip-archive-0.4.3-11lrb3wXzGi31DiUgTzUJU
license:              BSD-3-Clause
maintainer:           jgm@berkeley.edu
author:               John MacFarlane
homepage:             http://github.com/jgm/zip-archive
synopsis:             Library for creating and modifying zip archives.
description:
    The zip-archive library provides functions for creating, modifying, and
    extracting files from zip archives. The zip archive format is
    documented in <http://www.pkware.com/documents/casestudies/APPNOTE.TXT>.

    Certain simplifying assumptions are made about the zip archives: in
    particular, there is no support for strong encryption, zip files that
    span multiple disks, ZIP64, OS-specific file attributes, or compression
    methods other than Deflate. However, the library should be able to read
    the most common zip archives, and the archives it produces should be
    readable by all standard unzip programs.

    Archives are built and extracted in memory, so manipulating large zip
    files will consume a lot of memory. If you work with large zip files or
    need features not supported by this library, a better choice may be
    <http://hackage.haskell.org/package/zip zip>, which uses a
    memory-efficient streaming approach. However, zip can only read and
    write archives inside instances of MonadIO, so zip-archive is a better
    choice if you want to manipulate zip archives in "pure" contexts.

    As an example of the use of the library, a standalone zip archiver and
    extracter is provided in the source distribution.

category:             Codec
abi:                  fcadeeb9c9c45fe810d28119a25fad06
exposed:              True
exposed-modules:      Codec.Archive.Zip
import-dirs:          /usr/lib/ghc-9.0.2/site-local/zip-archive-0.4.3
library-dirs:         /usr/lib/ghc-9.0.2/site-local/zip-archive-0.4.3
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-zip-archive
hs-libraries:         HSzip-archive-0.4.3-11lrb3wXzGi31DiUgTzUJU
depends:
    array-0.5.4.0 base-4.15.1.0 binary-0.8.8.0 bytestring-0.10.12.1
    containers-0.6.4.1 digest-0.0.1.7-1FcF5IsvdnF8LdjR2KH0Uo
    directory-1.3.6.2 filepath-1.4.2.1 mtl-2.2.2 pretty-1.1.3.6
    text-1.2.5.0 time-1.9.3 unix-2.7.2.2
    zlib-0.6.3.0-8yAGwyuZ2uAGq492iT1L3K

haddock-interfaces:   /usr/share/doc/haskell-zip-archive/html/zip-archive.haddock
haddock-html:         /usr/share/doc/haskell-zip-archive/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-zip-archive-0.4.3-11-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-zip-archive.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 zip-archive
version:              0.4.3
visibility:           public
id:                   zip-archive-0.4.3-7OzTQLnX5FjD1Am7AiLfT
key:                  zip-archive-0.4.3-7OzTQLnX5FjD1Am7AiLfT
license:              BSD-3-Clause
maintainer:           jgm@berkeley.edu
author:               John MacFarlane
homepage:             http://github.com/jgm/zip-archive
synopsis:             Library for creating and modifying zip archives.
description:
    The zip-archive library provides functions for creating, modifying, and
    extracting files from zip archives. The zip archive format is
    documented in <http://www.pkware.com/documents/casestudies/APPNOTE.TXT>.

    Certain simplifying assumptions are made about the zip archives: in
    particular, there is no support for strong encryption, zip files that
    span multiple disks, ZIP64, OS-specific file attributes, or compression
    methods other than Deflate. However, the library should be able to read
    the most common zip archives, and the archives it produces should be
    readable by all standard unzip programs.

    Archives are built and extracted in memory, so manipulating large zip
    files will consume a lot of memory. If you work with large zip files or
    need features not supported by this library, a better choice may be
    <http://hackage.haskell.org/package/zip zip>, which uses a
    memory-efficient streaming approach. However, zip can only read and
    write archives inside instances of MonadIO, so zip-archive is a better
    choice if you want to manipulate zip archives in "pure" contexts.

    As an example of the use of the library, a standalone zip archiver and
    extracter is provided in the source distribution.

category:             Codec
abi:                  0443adac6a3a2823e6d4418dfee2d80a
exposed:              True
exposed-modules:      Codec.Archive.Zip
import-dirs:          /usr/lib/ghc-9.0.2/site-local/zip-archive-0.4.3
library-dirs:         /usr/lib/ghc-9.0.2/site-local/zip-archive-0.4.3
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-zip-archive
hs-libraries:         HSzip-archive-0.4.3-7OzTQLnX5FjD1Am7AiLfT
depends:
    array-0.5.4.0 base-4.15.1.0 binary-0.8.8.0 bytestring-0.10.12.1
    containers-0.6.4.1 digest-0.0.1.7-1FcF5IsvdnF8LdjR2KH0Uo
    directory-1.3.6.2 filepath-1.4.2.1 mtl-2.2.2 pretty-1.1.3.6
    text-1.2.5.0 time-1.9.3 unix-2.7.2.2
    zlib-0.6.3.0-KGB6WSQ4p2xLPLJOOhe04c

haddock-interfaces:   /usr/share/doc/haskell-zip-archive/html/zip-archive.haddock
haddock-html:         /usr/share/doc/haskell-zip-archive/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
